From c2864a82a053647757bf931851bcba107abf8741 Mon Sep 17 00:00:00 2001
From: Marko Lindqvist <cazfi74@gmail.com>
Date: Sat, 17 May 2025 05:09:23 +0300
Subject: [PATCH 24/24] Change "behaviour" to "behavior"

See RM #1397

Signed-off-by: Marko Lindqvist <cazfi74@gmail.com>
---
 ai/default/aitools.c            |  6 +++---
 ai/default/daidata.h            | 12 ++++++------
 ai/default/daidiplomacy.c       |  6 +++---
 client/audio_sdl.c              |  2 +-
 client/citydlg_common.c         |  2 +-
 client/gui-gtk-3.22/editprop.c  |  4 ++--
 client/gui-gtk-4.0/editprop.c   |  4 ++--
 client/mapctrl_common.c         |  2 +-
 client/options.c                |  2 +-
 client/tilespec.c               |  2 +-
 common/aicore/citymap.c         |  2 +-
 common/aicore/path_finding.h    |  8 ++++----
 common/aicore/pf_tools.c        | 10 +++++-----
 common/chat.h                   |  2 +-
 data/alien/nations.ruleset      |  2 +-
 data/civ1/nations.ruleset       |  2 +-
 data/civ2/nations.ruleset       |  2 +-
 data/default/nationlist.ruleset |  2 +-
 data/helpdata.txt               |  2 +-
 data/ruledit/comments-3.2.txt   |  2 +-
 data/stub/nations.ruleset       |  2 +-
 doc/FAQ                         |  2 +-
 doc/HACKING                     |  2 +-
 doc/README.AI                   |  8 ++++----
 doc/README.rulesets             |  2 +-
 server/cityturn.c               |  2 +-
 server/savegame/savecompat.c    |  6 +++---
 server/unittools.c              |  2 +-
 utility/fc_utf8.c               |  2 +-
 utility/iterator.h              |  2 +-
 utility/rand.c                  | 12 ++++++------
 utility/support.c               |  2 +-
 32 files changed, 60 insertions(+), 60 deletions(-)

diff --git a/ai/default/aitools.c b/ai/default/aitools.c
index 7734786ae8..bebb064811 100644
--- a/ai/default/aitools.c
+++ b/ai/default/aitools.c
@@ -548,7 +548,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
   if (unit_has_type_flag(punit, UTYF_SETTLERS)) {
     parameter->get_TB = no_fights;
   } else if (long_path && unit_is_cityfounder(punit)) {
-    /* Default tile behaviour;
+    /* Default tile behavior;
      * move as far along the path to the destination as we can;
      * that is, ignore the presence of enemy units when computing the
      * path.
@@ -564,7 +564,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
     parameter->get_TB = no_fights;
   } else if (is_losing_hp(punit)) {
     /* Losing hitpoints over time (helicopter in default rules) */
-    /* Default tile behaviour */
+    /* Default tile behavior */
   } else if (utype_may_act_at_all(unit_type_get(punit))) {
     switch (unit_data->task) {
     case AIUNIT_AUTO_SETTLER:
@@ -585,7 +585,7 @@ void dai_fill_unit_param(struct ai_type *ait, struct pf_parameter *parameter,
       parameter->get_TB = no_fights;
       break;
     case AIUNIT_NONE:
-      /* Default tile behaviour */
+      /* Default tile behavior */
       break;
     }
   } else {
diff --git a/ai/default/daidata.h b/ai/default/daidata.h
index 80b169bf9c..74791ed326 100644
--- a/ai/default/daidata.h
+++ b/ai/default/daidata.h
@@ -29,15 +29,15 @@
 struct player;
 
 enum winning_strategy {
-  WIN_OPEN,     /* still undetermined */
-  WIN_WAR,      /* we have no other choice than to crush all opposition */
-  WIN_SPACE,    /* we will race for space, peace very important */
-  WIN_CAPITAL   /* we cannot win unless we take war_target's capital */
+  WIN_OPEN,     /* Still undetermined */
+  WIN_WAR,      /* We have no other choice than to crush all opposition */
+  WIN_SPACE,    /* We will race for space, peace very important */
+  WIN_CAPITAL   /* We cannot win unless we take war_target's capital */
 };
 
 #define SPECENUM_NAME war_reason
-#define SPECENUM_VALUE0 DAI_WR_BEHAVIOUR
-#define SPECENUM_VALUE0NAME "Behaviour"
+#define SPECENUM_VALUE0 DAI_WR_BEHAVIOR
+#define SPECENUM_VALUE0NAME "Behavior"
 #define SPECENUM_VALUE1 DAI_WR_SPACE
 #define SPECENUM_VALUE1NAME "Space"
 #define SPECENUM_VALUE2 DAI_WR_EXCUSE
diff --git a/ai/default/daidiplomacy.c b/ai/default/daidiplomacy.c
index 2aeddce3ce..aef8107bec 100644
--- a/ai/default/daidiplomacy.c
+++ b/ai/default/daidiplomacy.c
@@ -1357,7 +1357,7 @@ static void dai_go_to_war(struct ai_type *ait, struct player *pplayer,
                      player_name(pplayer));
     adip->countdown = -10;
     break;
-  case DAI_WR_BEHAVIOUR:
+  case DAI_WR_BEHAVIOR:
     dai_diplo_notify(target,
                      _("*%s (AI)* I have tolerated your vicious antics "
                        "long enough! To war!"),
@@ -1508,7 +1508,7 @@ static void war_countdown(struct ai_type *ait, struct player *pplayer,
                          "Long live our glorious alliance!"),
                        player_name(pplayer));
       break;
-    case DAI_WR_BEHAVIOUR:
+    case DAI_WR_BEHAVIOR:
     case DAI_WR_EXCUSE:
       dai_diplo_notify(ally,
                        PL_("*%s (AI)* %s has grossly violated their treaties "
@@ -1623,7 +1623,7 @@ void dai_diplomacy_actions(struct ai_type *ait, struct player *pplayer)
         && dai_diplomacy_get(ait, pplayer, aplayer)->countdown == -1) {
       DIPLO_LOG(ait, LOG_DIPL2, pplayer, aplayer, "Plans war in revenge");
       war_countdown(ait, pplayer, aplayer, map_size_checked(),
-                    DAI_WR_BEHAVIOUR);
+                    DAI_WR_BEHAVIOR);
     }
   } players_iterate_end;
 
diff --git a/client/audio_sdl.c b/client/audio_sdl.c
index 3f7376aa1c..2e3de97755 100644
--- a/client/audio_sdl.c
+++ b/client/audio_sdl.c
@@ -45,7 +45,7 @@ struct sample {
 };
 
 /* Sounds don't sound good on Windows unless the buffer size is 4k,
- * but this seems to cause strange behaviour on other systems,
+ * but this seems to cause strange behavior on other systems,
  * such as a delay before playing the sound. */
 #ifdef FREECIV_MSWINDOWS
 const size_t buf_size = 4096;
diff --git a/client/citydlg_common.c b/client/citydlg_common.c
index 03c30d0c7c..84db6dba92 100644
--- a/client/citydlg_common.c
+++ b/client/citydlg_common.c
@@ -528,7 +528,7 @@ static void city_sum_add_real(struct city_sum *sum, double value,
 {
   size_t i;
 
-  /* Likely to lead to quadratic behaviour, but who cares: */
+  /* Likely to lead to quadratic behavior, but who cares: */
   for (i = 0; i < sum->n; i++) {
     fc_assert(sum->sums != NULL);
     if ((strcmp(sum->sums[i].posdesc, posdesc) == 0)
diff --git a/client/gui-gtk-3.22/editprop.c b/client/gui-gtk-3.22/editprop.c
index e67fb094b3..4f3f364838 100644
--- a/client/gui-gtk-3.22/editprop.c
+++ b/client/gui-gtk-3.22/editprop.c
@@ -6423,7 +6423,7 @@ void property_editor_reload(struct property_editor *pe,
   lists of patterns. A pattern may be preceded by '!' to have its result
   negated.
 
-  NB: If you change the behaviour of this function, be sure to update
+  NB: If you change the behavior of this function, be sure to update
   the filter tooltip in property_page_new().
 ****************************************************************************/
 static struct property_filter *property_filter_new(const char *filter)
@@ -6497,7 +6497,7 @@ static struct property_filter *property_filter_new(const char *filter)
   a|b&c - Matches all properties whose names contain either an "a",
           or contain both "b" and "c".
 
-  NB: If you change the behaviour of this function, be sure to update
+  NB: If you change the behavior of this function, be sure to update
   the filter tooltip in property_page_new().
 ****************************************************************************/
 static bool property_filter_match(struct property_filter *pf,
diff --git a/client/gui-gtk-4.0/editprop.c b/client/gui-gtk-4.0/editprop.c
index e0c0e57c7a..6e7fcd5993 100644
--- a/client/gui-gtk-4.0/editprop.c
+++ b/client/gui-gtk-4.0/editprop.c
@@ -6447,7 +6447,7 @@ void property_editor_reload(struct property_editor *pe,
   lists of patterns. A pattern may be preceded by '!' to have its result
   negated.
 
-  NB: If you change the behaviour of this function, be sure to update
+  NB: If you change the behavior of this function, be sure to update
   the filter tooltip in property_page_new().
 ****************************************************************************/
 static struct property_filter *property_filter_new(const char *filter)
@@ -6521,7 +6521,7 @@ static struct property_filter *property_filter_new(const char *filter)
   a|b&c - Matches all properties whose names contain either an "a",
           or contain both "b" and "c".
 
-  NB: If you change the behaviour of this function, be sure to update
+  NB: If you change the behavior of this function, be sure to update
   the filter tooltip in property_page_new().
 ****************************************************************************/
 static bool property_filter_match(struct property_filter *pf,
diff --git a/client/mapctrl_common.c b/client/mapctrl_common.c
index 12f8e95540..fa8fd2e43c 100644
--- a/client/mapctrl_common.c
+++ b/client/mapctrl_common.c
@@ -55,7 +55,7 @@ static int rec_w, rec_h;                /* width, heigth in pixels */
 bool rbutton_down = FALSE;
 bool rectangle_active = FALSE;
 
-/* This changes the behaviour of left mouse
+/* This changes the behavior of left mouse
    button in Area Selection mode. */
 bool tiles_hilited_cities = FALSE;
 
diff --git a/client/options.c b/client/options.c
index d400c5412c..f6479214d0 100644
--- a/client/options.c
+++ b/client/options.c
@@ -6047,7 +6047,7 @@ void options_load(void)
 
   /* More backwards compatibility, for removed options that had been
    * folded into then-existing options. Here, the backwards-compatibility
-   * behaviour overrides the "destination" option. */
+   * behavior overrides the "destination" option. */
 
   /* Removed in 2.4 */
   if (!secfile_lookup_bool_default(sf, TRUE,
diff --git a/client/tilespec.c b/client/tilespec.c
index eaa43289d5..be2c929e38 100644
--- a/client/tilespec.c
+++ b/client/tilespec.c
@@ -7163,7 +7163,7 @@ void tileset_init(struct tileset *t)
   views.
 
   NB: The 'layer' argument is NOT a LAYER_* value, but rather one of 0, 1, 2.
-  Using other values for 'layer' here will result in undefined behaviour. ;)
+  Using other values for 'layer' here will result in undefined behavior. ;)
 ****************************************************************************/
 int fill_basic_terrain_layer_sprite_array(struct tileset *t,
                                           struct drawn_sprite *sprs,
diff --git a/common/aicore/citymap.c b/common/aicore/citymap.c
index b8ad1a1dbc..aed612ef06 100644
--- a/common/aicore/citymap.c
+++ b/common/aicore/citymap.c
@@ -45,7 +45,7 @@
  * the negative of the ID of the city or unit that has reserved the
  * tile.
  *
- * Code that uses the citymap should modify its behaviour based on
+ * Code that uses the citymap should modify its behavior based on
  * positive values encountered, and never attempt to steal a tile
  * which has a negative value.
  */
diff --git a/common/aicore/path_finding.h b/common/aicore/path_finding.h
index 361a6dac10..243da31eef 100644
--- a/common/aicore/path_finding.h
+++ b/common/aicore/path_finding.h
@@ -56,7 +56,7 @@ extern "C" {
  *   The intended meaning for EC is "how much we want to avoid this tile",
  *   see DISCUSSION below for more.
  *
- *   tile behaviour (TB): the extra information about a tile which
+ *   tile behavior (TB): the extra information about a tile which
  *   tells us whether we can enter and leave tile as normal (see enum
  *   tile_behavior).
  *
@@ -124,7 +124,7 @@ extern "C" {
  * paths/tiles we want to consider. For example, a trireme might want to
  * never enter deep sea. A chariot, would like to find paths going to
  * enemy cities but not going _through_ them. This can be achieved
- * through an additional tile_behaviour callback, which would return
+ * through an additional tile_behavior callback, which would return
  * TB_IGNORE for tiles we don't want to visit and TB_DONT_LEAVE for tiles
  * we won't be able to leave (at least alive).
  *
@@ -146,7 +146,7 @@ extern "C" {
  *
  *
  * FORMULAE:
- *   For calculating total_MC (given particular tile_behaviour)
+ *   For calculating total_MC (given particular tile_behavior)
  *     total_MC = ((turn + 1) * move_rate - moves_left)
  *
  *   For calculating total_CC:
@@ -255,7 +255,7 @@ extern "C" {
  * not guaranteed to get the one with the least steps in it. If you care,
  * specifying EC to be 1 will do the job.
  * 3. To prevent AI from thinking that it can pass through "chokepoints"
- * controlled by enemy cities, you can specify tile behaviour of each
+ * controlled by enemy cities, you can specify tile behavior of each
  * occupied enemy city to be TB_DONT_LEAVE.
  */
 
diff --git a/common/chat.h b/common/chat.h
index 5d8f7a3b3b..b04ab2130d 100644
--- a/common/chat.h
+++ b/common/chat.h
@@ -14,7 +14,7 @@
 #define FC__CHAT_H
 
 /* Definitions related to interpreting chat messages.
- * Behaviour generally can't be changed at whim because client and
+ * Behavior generally can't be changed at whim because client and
  * server are assumed to agree on these details. */
 
 #ifdef __cplusplus
diff --git a/data/alien/nations.ruleset b/data/alien/nations.ruleset
index 8d41fae502..f2906cc1ba 100644
--- a/data/alien/nations.ruleset
+++ b/data/alien/nations.ruleset
@@ -91,7 +91,7 @@ rule_name = "all"
 
 ; Descriptions of nation groups
 ; These are more cosmetic than sets; they affect the "pick nation" dialog,
-; random nation selection, and possibly ruleset behaviour.
+; random nation selection, and possibly ruleset behavior.
 ; It`s OK to not define any nation groups at all.
 ; name          = name of the group (used adjectivally)
 ; hidden        = TRUE to not include this group in the "pick nation" dialog
diff --git a/data/civ1/nations.ruleset b/data/civ1/nations.ruleset
index 656850c331..49c19f4968 100644
--- a/data/civ1/nations.ruleset
+++ b/data/civ1/nations.ruleset
@@ -89,7 +89,7 @@ rule_name = "all"
 
 ; Descriptions of nation groups
 ; These are more cosmetic than sets; they affect the "pick nation" dialog,
-; random nation selection, and possibly ruleset behaviour.
+; random nation selection, and possibly ruleset behavior.
 ; It`s OK to not define any nation groups at all.
 ; name          = name of the group (used adjectivally)
 ; hidden        = TRUE to not include this group in the "pick nation" dialog
diff --git a/data/civ2/nations.ruleset b/data/civ2/nations.ruleset
index af0bcc406d..e9fa91cd4f 100644
--- a/data/civ2/nations.ruleset
+++ b/data/civ2/nations.ruleset
@@ -91,7 +91,7 @@ rule_name = "all"
 
 ; Descriptions of nation groups
 ; These are more cosmetic than sets; they affect the "pick nation" dialog,
-; random nation selection, and possibly ruleset behaviour.
+; random nation selection, and possibly ruleset behavior.
 ; It`s OK to not define any nation groups at all.
 ; name          =  name of the group (used adjectivally)
 ; hidden        = TRUE to not include this group in the "pick nation" dialog
diff --git a/data/default/nationlist.ruleset b/data/default/nationlist.ruleset
index c413b4b161..636ad9baf9 100644
--- a/data/default/nationlist.ruleset
+++ b/data/default/nationlist.ruleset
@@ -47,7 +47,7 @@ than English.\
 
 ; Descriptions of nation groups
 ; These are more cosmetic than sets; they affect the "pick nation" dialog,
-; random nation selection, and possibly ruleset behaviour.
+; random nation selection, and possibly ruleset behavior.
 ; It`s OK to not define any nation groups at all.
 ; name          = name of the group (used adjectivally)
 ; hidden        = TRUE to not include this group in the "pick nation" dialog
diff --git a/data/helpdata.txt b/data/helpdata.txt
index 4a207563d9..b645432b8b 100644
--- a/data/helpdata.txt
+++ b/data/helpdata.txt
@@ -850,7 +850,7 @@ where no citizens are naturally content, angry citizens will appear; \
 these must all be made merely unhappy before any unhappy citizens can \
 be made content, but in all other respects behave as unhappy citizens.\
 "),
-; Behaviour of angry citizens is actually a bit more complicated than
+; Behavior of angry citizens is actually a bit more complicated than
 ; this. See city_refresh_from_main_map() in common/city.c.
 _("\
 Luxury makes citizens happy. For every two luxury points a city \
diff --git a/data/ruledit/comments-3.2.txt b/data/ruledit/comments-3.2.txt
index 5dd2b2ce41..b635c33397 100644
--- a/data/ruledit/comments-3.2.txt
+++ b/data/ruledit/comments-3.2.txt
@@ -1213,7 +1213,7 @@ nationgroups = "\
 \n\
 ; Descriptions of nation groups\n\
 ; These are more cosmetic than sets; they affect the \"pick nation\" dialog,\n\
-; random nation selection, and possibly ruleset behaviour.\n\
+; random nation selection, and possibly ruleset behavior.\n\
 ; It`s OK to not define any nation groups at all.\n\
 ; name          = name of the group (used adjectivally)\n\
 ; hidden        = TRUE to not include this group in the \"pick nation\" dialog\n\
diff --git a/data/stub/nations.ruleset b/data/stub/nations.ruleset
index 9096e50b40..2a0c8f65f2 100644
--- a/data/stub/nations.ruleset
+++ b/data/stub/nations.ruleset
@@ -76,7 +76,7 @@ rule_name = "all"
 
 ; Descriptions of nation groups
 ; These are more cosmetic than sets; they affect the "pick nation" dialog,
-; random nation selection, and possibly ruleset behaviour.
+; random nation selection, and possibly ruleset behavior.
 ; It`s OK to not define any nation groups at all.
 ; name 		= name of the group (used adjectivally)
 ; hidden        = TRUE to not include this group in the "pick nation" dialog
diff --git a/doc/FAQ b/doc/FAQ
index 2b5557cccf..3058dc8fc2 100644
--- a/doc/FAQ
+++ b/doc/FAQ
@@ -389,7 +389,7 @@ games?
    So the goal of compatibility is mainly used as a limiting factor in
    development: when a new feature is added to Freeciv that makes gameplay
    different, it is generally implemented in such a way that the
-   "traditional" behaviour remains available as an option. However, we're
+   "traditional" behavior remains available as an option. However, we're
    not aiming for absolute 100% compatibility; in particular, we're not
    aiming for bug-compatibility.
 
diff --git a/doc/HACKING b/doc/HACKING
index b03b637610..58ffa812cd 100644
--- a/doc/HACKING
+++ b/doc/HACKING
@@ -835,7 +835,7 @@ a crude detection of inland seas or lakes, which should be improved upon).
 Tile ownership is decided only by the server, and sent to the clients, which
 draw border lines between tiles of differing ownership. Owner information is
 sent for all tiles that are known by a client, whether or not they are fogged.
-A patch to convert this to "semi-fogged" behaviour, whereby clients receive
+A patch to convert this to "semi-fogged" behavior, whereby clients receive
 limited information about non-neighboring and unseen enemies, is available
 at http://freecivac.sf.net/.
 
diff --git a/doc/README.AI b/doc/README.AI
index 062d44c355..ff8b8b1230 100644
--- a/doc/README.AI
+++ b/doc/README.AI
@@ -202,8 +202,8 @@ FERRY SYSTEM
 The ferry (i.e. boats transporting land units) system of Freeciv is
 probably better described by statistical mechanics than by logic.
 Both ferries and prospective passenger (PP) move around in what looks
-like a random fashion, trying to get closer to each other.  On
-average, they succeed.  This behaviour has good reasons behind it, is
+like a random fashion, trying to get closer to each other.
+On average, they succeed. This behavior has good reasons behind it, is
 hell to debug but means that small bugs don't affect overall picture
 visibly (and stay unfixed as a result).
 
@@ -217,7 +217,7 @@ Because most units recalculate their destination every turn, ignoring
 prior arrangements is the only good strategy -- it means that a boat
 will not rely on the PP to notify it when it's not needed anymore.
 This is not very effective but can only be changed when the PPs behave
-more responsibly.  See diplomat code for more responsible behaviour --
+more responsibly. See diplomat code for more responsible behavior --
 they try to check if the old target is still good before trying to
 find a new one.
 
@@ -246,7 +246,7 @@ Now they exist in parallel, although developed to a different degree.
 DIPLOMACY
 =========
 
-The AI's diplomatic behaviour is current only regulated by the
+The AI's diplomatic behavior is current only regulated by the
 'diplomacy' server setting.
 
 Easier AI levels propose cease-fire on first contact.
diff --git a/doc/README.rulesets b/doc/README.rulesets
index a04e26fd32..09504d0f32 100644
--- a/doc/README.rulesets
+++ b/doc/README.rulesets
@@ -12,7 +12,7 @@ Quickstart:
 
 - To play Freeciv normally: don't do anything special; the new
   features all have defaults which give the standard Freeciv
-  behaviour.
+  behavior.
 
 - To play a game with rules more like Civ1, start the server with:
        ./fcser -r data/civ1.serv
diff --git a/server/cityturn.c b/server/cityturn.c
index ed334bc7cd..c458353ac4 100644
--- a/server/cityturn.c
+++ b/server/cityturn.c
@@ -3584,7 +3584,7 @@ static void update_city_activity(struct city *pcity)
     /* History can decrease, but never go below zero */
     pcity->history = MAX(pcity->history, 0);
 
-    /* Keep old behaviour when building new improvement could keep
+    /* Keep old behavior when building new improvement could keep
        city celebrating */
     if (!is_happy) {
       is_happy = city_happy(pcity);
diff --git a/server/savegame/savecompat.c b/server/savegame/savecompat.c
index 4b85a6e216..0197247748 100644
--- a/server/savegame/savecompat.c
+++ b/server/savegame/savecompat.c
@@ -436,7 +436,7 @@ static void compat_load_020400(struct loaddata *loading,
           for (p = 0; p < maxslots; p++) {
             l = p / 32;
             for (x = 0; x < xsize; x++) {
-              /* This test causes bit-shifts of >=32 (undefined behaviour), but
+              /* This test causes bit-shifts of >=32 (undefined behavior), but
                * on common platforms, information happens not to be lost, just
                * oddly arranged. */
               if (known_row_old[l * xsize + x] & (1u << (p - l * 8))) {
@@ -485,9 +485,9 @@ static void compat_load_020400(struct loaddata *loading,
         /* In 2.3.x and prior, saveturns=0 meant no turn-based saves.
          * This is now controlled by the "autosaves" setting. */
         if (!fc_strcasecmp("saveturns", name)) {
-          /* XXX: hardcodes details from GAME_AUTOSAVES_DEFAULT
+          /* XXX: Hardcodes details from GAME_AUTOSAVES_DEFAULT
            * and settings.c:autosaves_name() (but these defaults reflect
-           * 2.3's behaviour). */
+           * 2.3's behavior). */
           const char *const nosave = "GAMEOVER|QUITIDLE|INTERRUPT";
           const char *const save = "TURN|GAMEOVER|QUITIDLE|INTERRUPT";
           int nturns;
diff --git a/server/unittools.c b/server/unittools.c
index c4dc36410c..9e266d1af8 100644
--- a/server/unittools.c
+++ b/server/unittools.c
@@ -1558,7 +1558,7 @@ void transform_unit(struct unit *punit, const struct unit_type *to_unit,
    * knock some levels off. */
   lvls = utype_veteran_system(to_unit)->levels - 1;
   punit->veteran = MIN(punit->veteran, lvls);
-  /* Keeping the old behaviour, so first clip top, then reduce */
+  /* Keeping the old behavior, so first clip top, then reduce */
   punit->veteran = MAX(punit->veteran - vet_loss, 0);
 
   /* Scale HP and MP, rounding down. Be careful with integer arithmetic,
diff --git a/utility/fc_utf8.c b/utility/fc_utf8.c
index ec3f137c70..4082ed847a 100644
--- a/utility/fc_utf8.c
+++ b/utility/fc_utf8.c
@@ -420,7 +420,7 @@ char *fc_utf8_validate_rep_dup(const char *utf8_string)
   number of used bytes, used strlen() instead.
 
   NB: 'utf8_string' must be UTF-8 valid (see fc_utf8_validate()), or the
-  behaviour of this function will be unknown.
+  behavior of this function will be unknown.
 ****************************************************************************/
 size_t fc_utf8_strlen(const char *utf8_string)
 {
diff --git a/utility/iterator.h b/utility/iterator.h
index e3637f6362..e4abe5e6ab 100644
--- a/utility/iterator.h
+++ b/utility/iterator.h
@@ -26,7 +26,7 @@ extern "C" {
   Iterator base class. "Derived" iterators must have this struct as
   their first member (as a "vtable") and provide implementations of the
   "pure virtual" member functions. See the function comment headers
-  below for the expected behaviour of these functions.
+  below for the expected behavior of these functions.
 ***********************************************************************/
 struct iterator {
   void (*next)(struct iterator *it);
diff --git a/utility/rand.c b/utility/rand.c
index 1482ab7ad1..bc34306d6f 100644
--- a/utility/rand.c
+++ b/utility/rand.c
@@ -245,8 +245,8 @@ void fc_rand_set_state(RANDOM_STATE state)
 
 /*********************************************************************//**
   Test one aspect of randomness, using n numbers.
-  Reports results to LOG_TEST; with good randomness, behaviourchange
-  and behavioursame should be about the same size.
+  Reports results to LOG_TEST; with good randomness, behaviorchange
+  and behaviorsame should be about the same size.
   Tests current random state; saves and restores state, so can call
   without interrupting current sequence.
 *************************************************************************/
@@ -255,7 +255,7 @@ void test_random1(int n)
   RANDOM_STATE saved_state;
   int i, old_value = 0, new_value;
   bool didchange, olddidchange = FALSE;
-  int behaviourchange = 0, behavioursame = 0;
+  int behaviorchange = 0, behaviorsame = 0;
 
   saved_state = fc_rand_state();
   /* fc_srand(time(NULL)); */  /* Use current state */
@@ -266,9 +266,9 @@ void test_random1(int n)
       didchange = (new_value != old_value);
       if (i > 1) {              /* Have olddidchange */
         if (didchange != olddidchange) {
-          behaviourchange++;
+          behaviorchange++;
         } else {
-          behavioursame++;
+          behaviorsame++;
         }
       }
       olddidchange = didchange;
@@ -276,7 +276,7 @@ void test_random1(int n)
     old_value = new_value;
   }
   log_test("test_random1(%d) same: %d, change: %d",
-           n, behavioursame, behaviourchange);
+           n, behaviorsame, behaviorchange);
 
   /* Restore state: */
   fc_rand_set_state(saved_state);
diff --git a/utility/support.c b/utility/support.c
index a3ba2883d3..042568b4c2 100644
--- a/utility/support.c
+++ b/utility/support.c
@@ -784,7 +784,7 @@ bool fc_strrep(char *str, size_t len, const char *search,
   truncation occurred.
 
   Not sure about the asserts below, but they are easier than
-  trying to ensure correct behaviour on strange inputs.
+  trying to ensure correct behavior on strange inputs.
   In particular note that n == 0 is prohibited (e.g., since there
   must at least be room for a nul); could consider other options.
 ****************************************************************************/
diff --git a/common/aicore/pf_tools.c b/common/aicore/pf_tools.c
index 7c98bf453d..6b1778e8f1 100644
--- a/common/aicore/pf_tools.c
+++ b/common/aicore/pf_tools.c
@@ -80,7 +80,7 @@ static inline bool pf_attack_possible(const struct tile *ptile,
       }
       /* NB: if there are UTYF_NEVER_PROTECTS units on the tile, 'attack_any'
          has to get set TRUE at least once to enable an attack to the tile,
-         which is exactly correct behaviour. */
+         which is exactly correct behavior. */
     }
   } unit_list_iterate_end;
 
@@ -484,7 +484,7 @@ static unsigned amphibious_extra_cost(const struct tile *ptile,
 }
 
 
 /* ===================== Tile Behaviour Callbacks ==================== */
 
 /************************************************************************//**
   PF callback to prohibit going into the unknown.  Also makes sure we 
@@ -536,8 +536,8 @@ enum tile_behavior no_intermediate_fights(const struct tile *ptile,
   A callback for amphibious movement
 ****************************************************************************/
 static enum tile_behavior
-amphibious_behaviour(const struct tile *ptile, enum known_type known,
-                     const struct pf_parameter *param)
+amphibious_behavior(const struct tile *ptile, enum known_type known,
+                    const struct pf_parameter *param)
 {
   struct pft_amphibious *amphibious = param->data;
   const bool ferry_move = is_native_tile(amphibious->sea.utype, ptile);
@@ -1005,7 +1005,7 @@ void pft_fill_amphibious_parameter(struct pft_amphibious *parameter)
   parameter->combined.move_rate = move_rate;
   parameter->combined.get_MC = amphibious_move;
   parameter->combined.get_move_scope = amphibious_move_scope;
-  parameter->combined.get_TB = amphibious_behaviour;
+  parameter->combined.get_TB = amphibious_behavior;
   parameter->combined.get_EC = amphibious_extra_cost;
   if (NULL != parameter->land.is_pos_dangerous
       || NULL != parameter->sea.is_pos_dangerous) {
@@ -484,7 +484,7 @@ static unsigned amphibious_extra_cost(const struct tile *ptile,
 
 
-/* ===================== Tile Behaviour Callbacks ==================== */
+/* ===================== Tile Behavior Callbacks ===================== */
 
 /************************************************************************//**
-- 
2.47.2

